# MDTerp


[![image](https://img.shields.io/pypi/v/MDTerp.svg)](https://pypi.python.org/pypi/MDTerp)
[![image](https://img.shields.io/conda/vn/conda-forge/MDTerp.svg)](https://anaconda.org/conda-forge/MDTerp)


**A python project for interpreting molecular dynamics trajectory metastable state classifications from machine-learning models**


-   Free software: MIT License
-   Documentation: https://shams-mehdi.github.io/MDTerp
    

## Features

-   Scans your blackbox model trained on MD data for feature importance.
